OkapiPythonConnector
====

Some routines to connect OKAPI:Orbits software with python.

Dependencies:

* python3
* Python modules "requests"

Example: See okapi_pkg/tryout.py

For more information, go to www.okapiorbits.space/documentation
 
